@@ -4,7 +4,7 @@ from ... import errors
 
 class TopicsPlugin(Plugin):
     identity = "topics"
-    priority = 60
+    priority = 20
     validity = {
         "type": "object",
         "properties": {
@@ -24,7 +24,8 @@ class TopicsPlugin(Plugin):
     # Process
 
     def process_markup(self, markup):
-        markup.add_style("style.css")
-        markup.add_script("https://unpkg.com/tocbot@4.12.3/dist/tocbot.min.js")
-        markup.add_script("script.js")
-        markup.add_markup("markup.html", target="#livemark-left")
+        if self.document.path != "index":
+            markup.add_style("style.css")
+            markup.add_script("https://unpkg.com/tocbot@4.12.3/dist/tocbot.min.js")
+            markup.add_script("script.js")
+            markup.add_markup("markup.html", target="#livemark-right")
